@@ -29,6 +29,15 @@ FAILEDOPERATION_GETCAMROLEFAILED = 'FailedOperation.GetCamRoleFailed'
 # 调用cam服务失败。
 FAILEDOPERATION_GETCAMSERVERFAILED = 'FailedOperation.GetCamServerFailed'
 
+# 获取cvm 规格信息失败。
+FAILEDOPERATION_GETCVMCONFIGQUOTAFAILED = 'FailedOperation.GetCvmConfigQuotaFailed'
+
+# 调用cvm服务失败。
+FAILEDOPERATION_GETCVMSERVERFAILED = 'FailedOperation.GetCvmServerFailed'
+
+# 调去询价中心服务失败
+FAILEDOPERATION_GETTRADESERVERFAILED = 'FailedOperation.GetTradeServerFailed'
+
 # 操作失败，不支持pod。
 FAILEDOPERATION_NOTSUPPORTPOD = 'FailedOperation.NotSupportPod'
 
@@ -101,12 +110,18 @@ INTERNALERROR_WOODSERVERERROR = 'InternalError.WoodServerError'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 参数错误。
+INVALIDPARAMETER_APPIDRESOURCENOTMATCH = 'InvalidParameter.AppIdResourceNotMatch'
+
 # 展示策略错误。
 INVALIDPARAMETER_DISPLAYSTRATEGYNOTMATCH = 'InvalidParameter.DisplayStrategyNotMatch'
 
 # 参数错误。
 INVALIDPARAMETER_HALESSMASTERCOUNT = 'InvalidParameter.HALessMasterCount'
 
+# impala查询参数异常。
+INVALIDPARAMETER_IMPALAQUERYEXCEPTION = 'InvalidParameter.ImpalaQueryException'
+
 # Common节点数量无效。
 INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'
 
@@ -359,6 +374,9 @@ RESOURCENOTFOUND_CDBINFONOTFOUND = 'ResourceNotFound.CDBInfoNotFound'
 # 无法找到该实例。
 RESOURCENOTFOUND_CLUSTERNOTFOUND = 'ResourceNotFound.ClusterNotFound'
 
+# 无法找到指定的CVM实例。
+RESOURCENOTFOUND_CVMINSTANCENOTFOUND = 'ResourceNotFound.CvmInstanceNotFound'
+
 # 无法找到硬件信息。
 RESOURCENOTFOUND_HARDWAREINFONOTFOUND = 'ResourceNotFound.HardwareInfoNotFound'
 
