@@ -606,8 +606,8 @@ class EssClient(AbstractClient):
 
     def CreatePrepareFlow(self, request):
         """创建快速发起流程
-        适用场景：用户通过API 合同文件及签署信息，并可通过我们返回的URL在页面完成签署控件等信息的编辑与确认，快速发起合同.
-        注：该接口文件的resourceId 是通过上传文件之后获取的。
+        <br/>适用场景：用户通过API 合同文件及签署信息，并可通过我们返回的URL在页面完成签署控件等信息的编辑与确认，快速发起合同.
+        <br/>注：该接口文件的resourceId 是通过上传文件之后获取的。
 
         :param request: Request instance for CreatePrepareFlow.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreatePrepareFlowRequest`
@@ -1400,7 +1400,8 @@ class EssClient(AbstractClient):
 
 
     def UpdateIntegrationEmployees(self, request):
-        """更新员工信息(姓名，手机号，邮件、部门)，用户实名后无法更改姓名与手机号
+        """更新员工信息(姓名，手机号，邮件、部门)，用户实名后无法更改姓名与手机号。
+        可进行批量操作，Employees中的userID与openID二选一必填
 
         :param request: Request instance for UpdateIntegrationEmployees.
         :type request: :class:`tencentcloud.ess.v20201111.models.UpdateIntegrationEmployeesRequest`
