@@ -14,7 +14,7 @@
 # limitations under the License.
 
 
-# 帐号已欠费。
+# 账号已欠费。
 FAILEDOPERATION_ARREARSERROR = 'FailedOperation.ArrearsError'
 
 # 身份证CardSide类型错误
@@ -44,6 +44,9 @@ FAILEDOPERATION_ENGINERECOGNIZETIMEOUT = 'FailedOperation.EngineRecognizeTimeout
 # 身份证信息不合法（身份证号、姓名字段校验非法等）。
 FAILEDOPERATION_IDCARDINFOILLEGAL = 'FailedOperation.IdCardInfoIllegal'
 
+# 图片分辨率过小或身份证在原图中的占比过小
+FAILEDOPERATION_IDCARDTOOSMALL = 'FailedOperation.IdCardTooSmall'
+
 # 银行卡信息非法。
 FAILEDOPERATION_ILLEGALBANKCARDERROR = 'FailedOperation.IllegalBankCardError'
 
@@ -116,9 +119,6 @@ INVALIDPARAMETER_CONFIGFORMATERROR = 'InvalidParameter.ConfigFormatError'
 # 图片解码失败。
 INVALIDPARAMETER_ENGINEIMAGEDECODEFAILED = 'InvalidParameter.EngineImageDecodeFailed'
 
-# 无效的GTIN。
-INVALIDPARAMETER_INVALIDGTINERROR = 'InvalidParameter.InvalidGTINError'
-
 # 任务创建失败，文件URL非法。
 INVALIDPARAMETERVALUE_FILEURLILLEGALERROR = 'InvalidParameterValue.FileUrlIllegalError'
 
